/*
	===== Credits =====
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+ Romain Vauchelles                     romain.vauchelles@unistra.fr 		+
+ And Philippe Carl			philippe.carl@unistra.fr		+
+ CNRS 7213                             https://lbp.unistra.fr/			+
+ Plateforme d'imagerie Quantitative    https://piq.unistra.fr/		 	+
+ Last Update	3 May 2023							+
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

This macro is converting all images included in a .lif file to .tif files in a new folder.

This macro require the bioformat-importer plugin from University of Wisconsin-Madison.
https://www.openmicroscopy.org/bio-formats/
*/

 //**** Preparation ImageJ
	requires("1.54.d");
	ScreenClean();
	setBatchMode(true);

 //*** In and Out
	Dialog.create("Select LIF file");
	 Dialog.addFile("Please select a LIF file to be extracted","");
	Dialog.show();
	       PathZani	= Dialog.getString();
	            Dir	= PathZani.substring(0, (PathZani.lastIndexOf(File.separator)) + 1);
	           Name	= PathZani.substring((PathZani.lastIndexOf(File.separator) + 1), PathZani.lastIndexOf("."));
	   prefixlength	= lengthOf(Name) + 6;

		OutPath = Dir + "\\" + Name + " TIF";
		 texist	= 1;
		  Dupli	= File.exists(OutPath);
	while(Dupli == 1)
	  {
		texist++;
		OutPath = Dir + File.separator + Name + " TIF (" + texist + ")";
		Dupli = File.exists(OutPath);
	  }
	File.makeDirectory(OutPath);

//*** Open and Save
	//*amorce
	print("Extracting images from: " + Name);
	print("Destination folder:     " + OutPath);

	run("Bio-Formats Macro Extensions");
	Ext.setId(PathZani);
	Ext.getSeriesCount(seriesCount);
	print("Number of pictures:     " + seriesCount);		stringSeriesCount = "" + seriesCount;
	nbDigitsSeriesCount = lengthOf(stringSeriesCount);

	if (seriesCount==1)
		{
		 run("Bio-Formats Importer", "open=[" + PathZani + "] autoscale color_mode=Composite view=Hyperstack stack_order=XYCZT series_");
		 currentPict = getTitle();
		 getDimensions(curwidth, curheight, curchannels, curslices, curframes);
		saveAs("Tiff", OutPath + File.separator + IJ.pad(1, nbDigitsSeriesCount) + " -" + currentPict);
		print(IJ.pad(1, nbDigitsSeriesCount) + " -" + currentPict);
		close();
		}
	else
	 {
	 for(n = 1; n <= seriesCount; n++)
	  {
		run("Bio-Formats Importer", "open=[" + PathZani + "] autoscale color_mode=Composite view=Hyperstack stack_order=XYCZT series_" + n);
		currentPict = substring(getTitle(), prefixlength, lengthOf(getTitle()));
		getDimensions(curwidth, curheight, curchannels, curslices, curframes);
		saveAs("Tiff", OutPath + File.separator + IJ.pad(n, nbDigitsSeriesCount) + " -" + currentPict);
		print(IJ.pad(n, nbDigitsSeriesCount) + " -" + currentPict);
		close();
	  }
	 }
	print("Done_");
	exit();

     function ScreenClean()
      {	
	while (nImages > 0) close();
	WinOp = getList("window.titles");
	WinOp = Array.deleteValue(WinOp, "Command Finder");
	for(i = 0; i < WinOp.length; i++)
	close(WinOp[i]);
      }
